'use strict';

function _interopDefault (ex) { return (ex && (typeof ex === 'object') && 'default' in ex) ? ex['default'] : ex; }

var Libphonenumber = require('libphonenumber-js/min/index.commonjs');
var React = _interopDefault(require('react'));

/*! *****************************************************************************
Copyright (c) Microsoft Corporation.

Permission to use, copy, modify, and/or distribute this software for any
purpose with or without fee is hereby granted.

THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH
REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY
AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT,
INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM
LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR
OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR
PERFORMANCE OF THIS SOFTWARE.
***************************************************************************** */

function __rest(s, e) {
    var t = {};
    for (var p in s) if (Object.prototype.hasOwnProperty.call(s, p) && e.indexOf(p) < 0)
        t[p] = s[p];
    if (s != null && typeof Object.getOwnPropertySymbols === "function")
        for (var i = 0, p = Object.getOwnPropertySymbols(s); i < p.length; i++) {
            if (e.indexOf(p[i]) < 0 && Object.prototype.propertyIsEnumerable.call(s, p[i]))
                t[p[i]] = s[p[i]];
        }
    return t;
}

// A wrapped to import Libphonenumber.AsYouType by its default export to appease Webpack.
const AsYouType = Libphonenumber.AsYouType;

/**
 * Headless phone number input formatter.
 */
function PhoneFormatter(_a) {
    var _b;
    var { onChange, defaultCountry } = _a, props = __rest(_a, ["onChange", "defaultCountry"]);
    const [inputValue, setInputValue] = React.useState("");
    const [formatter] = React.useState(() => new AsYouType(defaultCountry));
    const [impossible, setImpossible] = React.useState(null);
    const onInputChange = (newValue) => {
        if (inputValue == newValue)
            return;
        // The as-you-type formatter only works with append-only inputs.
        // Changes other than append require a reset.
        const isAppend = newValue.length > inputValue.length &&
            newValue.slice(0, inputValue.length) == inputValue;
        if (isAppend) {
            const appended = newValue.slice(inputValue.length);
            setInputValue(formatter.input(appended));
        }
        else {
            // Reset the formatter, but do not reformat.
            // Doing so now will cause the user to loose their cursor position
            // Wait until blur or append to reformat.
            formatter.reset();
            formatter.input(newValue);
            setInputValue(newValue);
        }
        const number = formatter.getNumber();
        const e164 = number === null || number === void 0 ? void 0 : number.number;
        onChange(e164);
        if (impossible && number && number.isPossible())
            setImpossible(false);
    };
    React.useLayoutEffect(() => {
        var _a;
        const number = (_a = formatter.getNumber()) === null || _a === void 0 ? void 0 : _a.number;
        if (number != props.value) {
            // override the phone number if the field has a number and its e164 representation doesn't match the prop value.
            formatter.reset();
            setInputValue(props.value ? formatter.input(props.value) : "");
            const number = formatter.getNumber();
            setImpossible(number == null ? null : !number.isPossible());
            const e164 = number === null || number === void 0 ? void 0 : number.number;
            onChange(e164);
        }
    }, [props.value, formatter, inputValue, onChange]);
    const country = (_b = formatter.getNumber()) === null || _b === void 0 ? void 0 : _b.country;
    return (React.createElement(React.Fragment, null, props.children({
        country,
        impossible,
        inputValue,
        onInputChange,
        onBlur() {
            const number = formatter.getNumber();
            onChange(number === null || number === void 0 ? void 0 : number.number);
            if (!number)
                return setImpossible(null);
            // Check and update possibility
            const possible = number.isPossible();
            setImpossible(!possible);
            if (possible) {
                // Reformat the phone number as international
                formatter.reset();
                setInputValue(formatter.input(number.number));
            }
            else {
                // Format the phone number
                setInputValue(formatter.input(""));
            }
        },
    })));
}

module.exports = PhoneFormatter;
