import React from 'react';
import { AsYouType } from 'libphonenumber-js/min/index';

/**
 * Headless phone number input formatter.
 */
function PhoneFormatter({ onChange, defaultCountry, ...props }) {
    var _a;
    const [inputValue, setInputValue] = React.useState("");
    const [formatter] = React.useState(() => new AsYouType(defaultCountry));
    const [impossible, setImpossible] = React.useState(null);
    const onInputChange = (newValue) => {
        if (inputValue == newValue)
            return;
        // The as-you-type formatter only works with append-only inputs.
        // Changes other than append require a reset.
        const isAppend = newValue.length > inputValue.length &&
            newValue.slice(0, inputValue.length) == inputValue;
        if (isAppend) {
            const appended = newValue.slice(inputValue.length);
            setInputValue(formatter.input(appended));
        }
        else {
            // Reset the formatter, but do not reformat.
            // Doing so now will cause the user to loose their cursor position
            // Wait until blur or append to reformat.
            formatter.reset();
            formatter.input(newValue);
            setInputValue(newValue);
        }
        const number = formatter.getNumber();
        const e164 = number === null || number === void 0 ? void 0 : number.number;
        onChange(e164);
        if (impossible && number && number.isPossible())
            setImpossible(false);
    };
    React.useLayoutEffect(() => {
        var _a;
        const number = (_a = formatter.getNumber()) === null || _a === void 0 ? void 0 : _a.number;
        if (number != props.value) {
            // override the phone number if the field has a number and its e164 representation doesn't match the prop value.
            formatter.reset();
            setInputValue(props.value ? formatter.input(props.value) : "");
            const number = formatter.getNumber();
            setImpossible(number == null ? null : !number.isPossible());
            const e164 = number === null || number === void 0 ? void 0 : number.number;
            onChange(e164);
        }
    }, [props.value, formatter, inputValue, onChange]);
    const country = (_a = formatter.getNumber()) === null || _a === void 0 ? void 0 : _a.country;
    return (React.createElement(React.Fragment, null, props.children({
        country,
        impossible,
        inputValue,
        onInputChange,
        onBlur() {
            const number = formatter.getNumber();
            onChange(number === null || number === void 0 ? void 0 : number.number);
            if (!number)
                return setImpossible(null);
            // Check and update possibility
            const possible = number.isPossible();
            setImpossible(!possible);
            if (possible) {
                // Reformat the phone number as international
                formatter.reset();
                setInputValue(formatter.input(number.number));
            }
            else {
                // Format the phone number
                setInputValue(formatter.input(""));
            }
        },
    })));
}

export default PhoneFormatter;
